Package: optmatch
Version: 0.10.8
Title: Functions for Optimal Matching
Description: Distance based bipartite matching using minimum cost flow, oriented
    to matching of treatment and control groups in observational studies ('Hansen'
    and 'Klopfer' 2006 <doi:10.1198/106186006X137047>). Routines are provided to
    generate distances from generalised linear models (propensity score
    matching), formulas giving variables on which to limit matched distances,
    stratified or exact matching directives, or calipers, alone or in
    combination.
Authors@R: c(person("Ben", "Hansen", role = "aut", email = "ben.hansen@umich.edu"),
             person("Mark", "Fredrickson", role = "aut", email = "mark.m.fredrickson@gmail.com"),
             person("Josh", "Errickson", role = c("cre","aut"), email = "jerrick@umich.edu"),
             person("Josh", "Buckner", role = "aut"),
             person("Adam", "Rauh", role = "ctb"))
LazyData: true
Depends: R (>= 3.5.0)
LinkingTo: Rcpp
Imports: Rcpp, dplyr, stats, tibble, methods, graphics, rlemon
Suggests: RItools, boot, biglm, survey, testthat (>= 0.11.0), roxygen2,
        brglm, arm, knitr, rmarkdown, markdown, pander, xtable,
        rrelaxiv, magrittr
Enhances: CBPS, haven
License: MIT + file LICENSE
License_is_FOSS: yes
License_restricts_use: no
URL: http://optmat.ch, https://github.com/markmfredrickson/optmatch
BugReports: https://github.com/markmfredrickson/optmatch/issues
Additional_repositories: https://errickson.net/rrelaxiv
Collate: 'DenseMatrix.R' 'InfinitySparseMatrix.R' 'MCFSolutions.R'
        'Ops.optmatch.dlist.R' 'Optmatch-package.R' 'RcppExports.R'
        'abs.optmatch.dlist.R' 'boxplotMethods.R' 'caliper.R'
        'complementarySlackness.R' 'data.R' 'deprecated.R'
        'distUnion.R' 'edgelist.R' 'exactMatch.R' 'feasible.R'
        'fill.NAs.R' 'fmatch.R' 'fullmatch.R' 'makedist.R' 'match_on.R'
        'matched.R' 'matched.distances.R' 'matchfailed.R'
        'max.controls.cap.R' 'mdist.R' 'min.controls.cap.R'
        'optmatchS3.R' 'pairmatch.R' 'print.optmatch.R'
        'print.optmatch.dlist.R' 'scores.R' 'solve_reg_fm_prob.R'
        'solver.R' 'strata.R' 'stratumStructure.R' 'summary.ism.R'
        'summary.optmatch.R' 'utilities.R' 'zzz.R'
        'zzzDistanceSpecification.R'
VignetteBuilder: knitr
RoxygenNote: 7.3.2
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2024-09-18 18:18:56 UTC; josh
Author: Ben Hansen [aut],
  Mark Fredrickson [aut],
  Josh Errickson [cre, aut],
  Josh Buckner [aut],
  Adam Rauh [ctb]
Maintainer: Josh Errickson <jerrick@umich.edu>
Repository: CRAN
Date/Publication: 2024-09-19 06:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 14:09:34 UTC; unix
Archs: optmatch.so.dSYM
