# Generated by roxygen2: do not edit by hand

S3method("[",optmatch)
S3method(Ops,optmatch.dlist)
S3method(as.data.frame,EdgeList)
S3method(as.list,BlockedInfinitySparseMatrix)
S3method(as.list,DenseMatrix)
S3method(as.list,InfinitySparseMatrix)
S3method(as.matrix,DenseMatrix)
S3method(as.matrix,InfinitySparseMatrix)
S3method(as.matrix,optmatch.dlist)
S3method(boxplot,bigglm)
S3method(boxplot,glm)
S3method(boxplot,svyglm)
S3method(c,optmatch)
S3method(cbind,BlockedInfinitySparseMatrix)
S3method(cbind,InfinitySparseMatrix)
S3method(dim,EdgeList)
S3method(dim,InfinitySparseMatrix)
S3method(dim,optmatch.dlist)
S3method(dimnames,optmatch.dlist)
S3method(effectiveSampleSize,default)
S3method(effectiveSampleSize,factor)
S3method(effectiveSampleSize,table)
S3method(fullmatch,BlockedInfinitySparseMatrix)
S3method(fullmatch,InfinitySparseMatrix)
S3method(fullmatch,default)
S3method(fullmatch,matrix)
S3method(fullmatch,numeric)
S3method(fullmatch,optmatch.dlist)
S3method(match_on,"function")
S3method(match_on,InfinitySparseMatrix)
S3method(match_on,bigglm)
S3method(match_on,formula)
S3method(match_on,glm)
S3method(match_on,matrix)
S3method(match_on,numeric)
S3method(mdist,"function")
S3method(mdist,bigglm)
S3method(mdist,formula)
S3method(mdist,glm)
S3method(mdist,numeric)
S3method(mdist,optmatch.dlist)
S3method(num_eligible_matches,BlockedInfinitySparseMatrix)
S3method(num_eligible_matches,InfinitySparseMatrix)
S3method(num_eligible_matches,matrix)
S3method(num_eligible_matches,optmatch.dlist)
S3method(pairmatch,BlockedInfinitySparseMatrix)
S3method(pairmatch,InfinitySparseMatrix)
S3method(pairmatch,default)
S3method(pairmatch,matrix)
S3method(pairmatch,numeric)
S3method(pairmatch,optmatch.dlist)
S3method(print,optmatch)
S3method(print,stratumStructure)
S3method(print,summary.BlockedInfinitySparseMatrix)
S3method(print,summary.DenseMatrix)
S3method(print,summary.InfinitySparseMatrix)
S3method(print,summary.optmatch)
S3method(rbind,BlockedInfinitySparseMatrix)
S3method(rbind,InfinitySparseMatrix)
S3method(sort,BlockedInfinitySparseMatrix)
S3method(sort,InfinitySparseMatrix)
S3method(stratumStructure,default)
S3method(stratumStructure,optmatch)
S3method(subdim,BlockedInfinitySparseMatrix)
S3method(subdim,InfinitySparseMatrix)
S3method(subdim,matrix)
S3method(subdim,optmatch.dlist)
S3method(subset,InfinitySparseMatrix)
S3method(subset,optmatch.dlist)
S3method(summary,BlockedInfinitySparseMatrix)
S3method(summary,DenseMatrix)
S3method(summary,InfinitySparseMatrix)
S3method(summary,optmatch)
S3method(t,BlockedInfinitySparseMatrix)
S3method(t,EdgeList)
S3method(t,InfinitySparseMatrix)
S3method(update,optmatch)
export(LEMON)
export(antiExactMatch)
export(as.InfinitySparseMatrix)
export(caliper)
export(dbind)
export(distUnion)
export(effectiveSampleSize)
export(exactMatch)
export(fill.NAs)
export(findSubproblems)
export(full)
export(fullmatch)
export(getMaxProblemSize)
export(mahal.dist)
export(match_on)
export(matched)
export(matched.distances)
export(matchfailed)
export(maxCaliper)
export(maxControlsCap)
export(mdist)
export(minControlsCap)
export(minExactMatch)
export(num_eligible_matches)
export(optmatch_restrictions)
export(optmatch_same_distance)
export(pair)
export(pairmatch)
export(pscore.dist)
export(scores)
export(setMaxProblemSize)
export(standardization_scale)
export(strata)
export(stratumStructure)
export(subdim)
export(unmatched)
exportMethods("*")
exportMethods("+")
exportMethods("-")
exportMethods("/")
exportMethods("[")
exportMethods("[<-")
exportMethods("dimnames<-")
exportMethods(c)
exportMethods(dimnames)
exportMethods(exactMatch)
exportMethods(show)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,filter)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(graphics,boxplot)
importFrom(graphics,hist)
importFrom(methods,as)
importFrom(methods,callGeneric)
importFrom(methods,callNextMethod)
importFrom(methods,hasMethod)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,show)
importFrom(methods,slot)
importFrom(methods,validObject)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,contr.poly)
importFrom(stats,contrasts)
importFrom(stats,cov)
importFrom(stats,formula)
importFrom(stats,get_all_vars)
importFrom(stats,mad)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,optimize)
importFrom(stats,plogis)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,terms.formula)
importFrom(stats,update)
importFrom(stats,update.formula)
importFrom(tibble,as_tibble)
importFrom(tibble,enframe)
importFrom(tibble,tibble)
importFrom(utils,getS3method)
importFrom(utils,methods)
useDynLib(optmatch, .registration=TRUE)
